@@ -105,9 +105,10 @@ class safelist(list):
 
 def get_factor_value(
     factor_value: Value,
+    round_to_decimal_place: int = 2
 ) -> Union[str, int, float, bool, datetime.datetime]:
     _val_type, value = betterproto.which_one_of(factor_value, "value_type")
-    return value
+    return get_rounded_value(value, round_to_decimal_place)
 
 
 @dataclass
@@ -116,14 +117,14 @@ class FactorDimVal:
     value: Optional[any]
 
 
-def get_factor(dimension: str, factor: Factor) -> FactorDimVal:
+def get_factor(dimension: str, factor: Factor, round_to_decimal_place: int = 2) -> FactorDimVal:
     factor_type, _factor_data = betterproto.which_one_of(factor, "factor_type")
     if factor_type == "value":
-        return FactorDimVal(dimension, get_factor_value(factor.value))
+        return FactorDimVal(dimension, get_factor_value(factor.value, round_to_decimal_place))
     elif factor_type == "bin":
         return FactorDimVal(
             dimension,
-            f"{factor.bin.lower_bound}-{factor.bin.upper_bound} ({factor.bin.lower_bound_percentile}-{factor.bin.upper_bound_percentile} percentile)",
+            f"{get_rounded_value(factor.bin.lower_bound , round_to_decimal_place)}-{get_rounded_value(factor.bin.upper_bound , round_to_decimal_place)} ({get_rounded_value(factor.bin.lower_bound_percentile , round_to_decimal_place)}-{get_rounded_value(factor.bin.upper_bound_percentile , round_to_decimal_place)} percentile)",
         )
     elif factor_type == "keyword":
         return FactorDimVal(dimension, factor.keyword.keyword)
@@ -132,12 +133,11 @@ def get_factor(dimension: str, factor: Factor) -> FactorDimVal:
 
 
 def get_factors(
-    factors: Dict[str, Factor]
+    factors: Dict[str, Factor], round_to_decimal_place: int = 2
 ) -> Tuple[FactorDimVal, FactorDimVal, FactorDimVal]:
     converted_factors = safelist(
-        [get_factor(dim, fact) for dim, fact in factors.items()]
-    )
-
+        [get_factor(dim, fact, round_to_decimal_place) for dim, fact in factors.items()]
+    )    
     empty_factor = FactorDimVal(None, None)
     return (
         converted_factors.get(0),
@@ -161,10 +161,11 @@ def build_header_from_row(rows: List[Row]) -> List[HeaderColumn]:
 def get_rows_time_comparision(
     subgroups: List[KeyDriverAnalysisResultSegment],
     time_comparision: KeyDriverAnalysisResultTimeComparison,
+    round_to_decimal_place: int = 2
 ) -> List[Row]:
     rows = []
     for subgroup in subgroups:
-        factor_0, factor_1, factor_2 = get_factors(subgroup.factors)
+        factor_0, factor_1, factor_2 = get_factors(subgroup.factors, round_to_decimal_place)
 
         r = TimeCompareRow(
             subgroup_id=subgroup.id,
@@ -175,15 +176,15 @@ def get_rows_time_comparision(
             factor_1_value=factor_1.value,
             factor_2_dimension=factor_2.dimension,
             factor_2_value=factor_2.value,
-            previous_period_size=subgroup.time_comparison.previous_period_size,
-            recent_period_size=subgroup.time_comparison.recent_period_size,
-            previous_period_value=subgroup.time_comparison.previous_period_value,
-            recent_period_value=subgroup.time_comparison.recent_period_value,
+            previous_period_size=get_rounded_value(subgroup.time_comparison.previous_period_size, round_to_decimal_place),
+            recent_period_size=get_rounded_value(subgroup.time_comparison.recent_period_size, round_to_decimal_place),
+            previous_period_value=get_rounded_value(subgroup.time_comparison.previous_period_value, round_to_decimal_place),
+            recent_period_value=get_rounded_value(subgroup.time_comparison.recent_period_value, round_to_decimal_place),
             previous_period_start_date_inclusive=time_comparision.previous_period.start_date_inclusive,
             previous_period_end_date_inclusive=time_comparision.previous_period.end_date_inclusive,
             recent_period_start_date_inclusive=time_comparision.recent_period.start_date_inclusive,
             recent_period_end_date_inclusive=time_comparision.recent_period.end_date_inclusive,
-            impact=subgroup.impact,
+            impact=get_rounded_value(subgroup.impact, round_to_decimal_place),
         )
         rows.append(r)
 
@@ -193,27 +194,28 @@ def get_rows_time_comparision(
 def get_rows_group_comparision(
     subgroups: List[KeyDriverAnalysisResultSegment],
     group_comparision: KeyDriverAnalysisResultGroupComparison,
+    round_to_decimal_place: int = 2
 ) -> List[Row]:
     rows = []
     for subgroup in subgroups:
-        factor_0, factor_1, factor_2 = get_factors(subgroup.factors)
+        factor_0, factor_1, factor_2 = get_factors(subgroup.factors, round_to_decimal_place)
 
         r = GroupCompareRow(
             subgroup_id=subgroup.id,
             confidence=subgroup.confidence.name,
             factor_0_dimension=factor_0.dimension,
-            factor_0_value=factor_0.value,
+            factor_0_value=factor_0.value, 
             factor_1_dimension=factor_1.dimension,
-            factor_1_value=factor_1.value,
+            factor_1_value=factor_1.value, 
             factor_2_dimension=factor_2.dimension,
             factor_2_value=factor_2.value,
-            group_a_size=subgroup.group_comparison.group_a_size,
-            group_b_size=subgroup.group_comparison.group_b_size,
-            group_a_value=subgroup.group_comparison.group_a_value,
-            group_b_value=subgroup.group_comparison.group_b_value,
+            group_a_size=get_rounded_value(subgroup.group_comparison.group_a_size, round_to_decimal_place),
+            group_b_size=get_rounded_value(subgroup.group_comparison.group_b_size, round_to_decimal_place),
+            group_a_value=get_rounded_value(subgroup.group_comparison.group_a_value, round_to_decimal_place),
+            group_b_value=get_rounded_value(subgroup.group_comparison.group_b_value, round_to_decimal_place),
             group_a_name=group_comparision.group_a.name,
             group_b_name=group_comparision.group_b.name,
-            impact=subgroup.impact,
+            impact=get_rounded_value(subgroup.impact, round_to_decimal_place),
         )
         rows.append(r)
 
@@ -222,10 +224,11 @@ def get_rows_group_comparision(
 
 def get_rows_general_performance(
     subgroups: List[KeyDriverAnalysisResultSegment],
+    round_to_decimal_place: int = 2
 ) -> List[Row]:
     rows = []
     for subgroup in subgroups:
-        factor_0, factor_1, factor_2 = get_factors(subgroup.factors)
+        factor_0, factor_1, factor_2 = get_factors(subgroup.factors, round_to_decimal_place)
 
         r = GeneralPerformanceRow(
             subgroup_id=subgroup.id,
@@ -236,9 +239,9 @@ def get_rows_general_performance(
             factor_1_value=factor_1.value,
             factor_2_dimension=factor_2.dimension,
             factor_2_value=factor_2.value,
-            size=subgroup.general_performance.size,
-            value=subgroup.general_performance.value,
-            impact=subgroup.impact,
+            size=get_rounded_value(subgroup.general_performance.size, round_to_decimal_place),
+            value=get_rounded_value(subgroup.general_performance.value, round_to_decimal_place),
+            impact=get_rounded_value(subgroup.impact, round_to_decimal_place),
         )
         rows.append(r)
 
@@ -248,6 +251,7 @@ def get_rows_general_performance(
 def get_rows_trend(
     subgroups: List[TrendAnalysisResultSegment],
     overall_trends: List[TrendAnalysisResultTrend],
+    round_to_decimal_place: int = 2
 ) -> List[Row]:
     rows = []
 
@@ -260,17 +264,17 @@ def get_rows_trend(
             factor_1_value=None,
             factor_2_dimension=None,
             factor_2_value=None,
-            impact=otrend.trend,
+            impact=get_rounded_value(otrend.trend, round_to_decimal_place),
             start_date_inclusive=otrend.time_range.start_date_inclusive,
             end_date_inclusive=otrend.time_range.end_date_inclusive,
-            intercept=otrend.intercept,
-            slope=otrend.trend,
-            size=otrend.size,
+            intercept=get_rounded_value(otrend.intercept, round_to_decimal_place) ,
+            slope=get_rounded_value(otrend.trend, round_to_decimal_place) ,
+            size=get_rounded_value(otrend.size, round_to_decimal_place) ,
         )
         rows.append(r)
 
     for subgroup in subgroups:
-        factor_0, factor_1, factor_2 = get_factors(subgroup.factors)
+        factor_0, factor_1, factor_2 = get_factors(subgroup.factors, round_to_decimal_place)
 
         if factor_1.dimension is not None:
             if factor_2.dimension is not None:
@@ -292,19 +296,21 @@ def get_rows_trend(
                 factor_1_value=factor_1.value,
                 factor_2_dimension=factor_2.dimension,
                 factor_2_value=factor_2.value,
-                impact=subgroup.impact,
+                impact=get_rounded_value(subgroup.impact, round_to_decimal_place),
                 start_date_inclusive=trend.time_range.start_date_inclusive,
                 end_date_inclusive=trend.time_range.end_date_inclusive,
-                intercept=trend.intercept,
-                slope=trend.trend,
-                size=trend.size,
+                intercept=get_rounded_value(trend.intercept, round_to_decimal_place) ,
+                slope=get_rounded_value(trend.trend, round_to_decimal_place) ,
+                size=get_rounded_value(trend.size, round_to_decimal_place) ,
             )
             rows.append(r)
 
     return rows
+def get_rounded_value(value, round_to_decimal_place):
+    return round(value, round_to_decimal_place) if type(value) is float else value
 
 
-def _get_rows(result: AnalysisRunResultsResponse) -> List[Row]:
+def _get_rows(result: AnalysisRunResultsResponse, round_to_decimal_place: int = 2) -> List[Row]:
     # Under the assumption that an analysis can't be
     # more than one of [KDA, TD]
     if result.analysis_result.key_driver_analysis_result:
@@ -313,14 +319,14 @@ def _get_rows(result: AnalysisRunResultsResponse) -> List[Row]:
 
         if analysis_result.time_comparison:
             return get_rows_time_comparision(
-                subgroups, analysis_result.time_comparison
+                subgroups, analysis_result.time_comparison, round_to_decimal_place
             )
         elif analysis_result.group_comparison:
             return get_rows_group_comparision(
-                subgroups, analysis_result.group_comparison
+                subgroups, analysis_result.group_comparison, round_to_decimal_place
             )
         elif analysis_result.general_performance._serialized_on_wire:
-            return get_rows_general_performance(subgroups)
+            return get_rows_general_performance(subgroups, round_to_decimal_place)
         else:
             raise ValueError("Invalid key_driver_analysis_result")
 
@@ -328,12 +334,12 @@ def _get_rows(result: AnalysisRunResultsResponse) -> List[Row]:
         analysis_result = result.analysis_result.trend_analysis_result
         subgroups = analysis_result.segments
 
-        return get_rows_trend(subgroups, analysis_result.overall_trends)
+        return get_rows_trend(subgroups, analysis_result.overall_trends, round_to_decimal_place)
 
     else:
         raise ValueError("Invalid analysis_result")
 
 
-def to_table(result: AnalysisRunResultsResponse) -> LatestAnalysisResultTable:
-    rows = _get_rows(result)
+def to_table(result: AnalysisRunResultsResponse, round_to_decimal_place: int = 2) -> LatestAnalysisResultTable:
+    rows = _get_rows(result, round_to_decimal_place)
     return LatestAnalysisResultTable(build_header_from_row(rows), rows)
