@@ -24,7 +24,7 @@ from .formats import LatestAnalysisResultsFormats, Table
 from .latest_analysis_result import to_table
 from .proto.sisu.v1.api import (
     AnalysesListResponse,
-    AnalysisRequest,
+    AnalysisDimensionsListResponse,
     AnalysisRunResultsResponse,
     CreateDataSetRequestDataset,
     DataSetsResponse,
@@ -35,9 +35,12 @@ from .proto.sisu.v1.api import (
     GetProjectsListResponseListProjectResponse,
     GetSegmentDataResponse,
     MetricsListResponse,
+    ModifyAnalysisRequestAnalysis,
     ModifyAnalysisResponse,
     SetAnalysisFiltersRequest,
-    AnalysisDimensionsListResponse,
+    UpdateAnalysisRequestAnalysis,
+    UpdateAnalysisResponse,
+    WaterfallAnalysisResponse,
 )
 from .query_helpers import build_url, pathjoin, semver_parse
 from .version import __version__ as PYSISU_VERSION
@@ -191,6 +194,7 @@ class PySisu:
         params: dict = {"confidence_gte": "LOW"},
         auto_paginate: bool = True,
         format: LatestAnalysisResultsFormats = LatestAnalysisResultsFormats.TABLE,
+        round_to_decimal_place: int = 2,
         **kwargs,
     ) -> Union[AnalysisRunResultsResponse, Table]:
         assert type(params) is dict
@@ -204,7 +208,7 @@ class PySisu:
             result = self._auto_paginate(analysis_id, kwargs, result)
 
         if format == LatestAnalysisResultsFormats.TABLE:
-            return to_table(result)
+            return to_table(result, round_to_decimal_place)
         else:
             return result
 
@@ -270,7 +274,7 @@ class PySisu:
         url_path = build_url(self._url, pathjoin(*path), {})
         return GetSegmentDataResponse().from_dict(
             self._call_sisu_api(
-                url_path, request_method="POST", json=body.to_json()
+                url_path, request_method="POST", json=body.to_dict()
             )
         )
 
@@ -292,18 +296,45 @@ class PySisu:
 
     def modify_analysis(
         self,
-        project_id: int,
         analysis_id: int,
-        modify_analysis_req: AnalysisRequest,
+        modify_analysis_req: ModifyAnalysisRequestAnalysis,
     ) -> ModifyAnalysisResponse:
-        path = [f"api/v1/projects/{project_id}/analyses/{analysis_id}"]
+        path = [f"api/v1/analyses/{analysis_id}"]
         url_path = build_url(self._url, pathjoin(*path), {})
         return ModifyAnalysisResponse().from_dict(
-            self._call_sisu_api(url_path, request_method="PATCH", json=modify_analysis_req.to_json()))
+            self._call_sisu_api(
+                url_path,
+                request_method="PATCH",
+                json=modify_analysis_req.to_dict(),
+            )
+        )
 
-    def get_analysis_dimensions_list(self, analysis_id) -> AnalysisDimensionsListResponse:
+    def update_analysis(
+        self,
+        analysis_id: int,
+        modify_analysis_req: UpdateAnalysisRequestAnalysis,
+    ) -> UpdateAnalysisResponse:
+        path = [f"api/v1/analyses/{analysis_id}"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return UpdateAnalysisResponse().from_dict(
+            self._call_sisu_api(
+                url_path,
+                request_method="PUT",
+                json=modify_analysis_req.to_dict(),
+            )
+        )
+
+    def get_analysis_dimensions_list(
+        self, analysis_id
+    ) -> AnalysisDimensionsListResponse:
         path = [f"api/v1/analyses/{analysis_id}/dimensions"]
         url_path = build_url(self._url, pathjoin(*path), {})
         return AnalysisDimensionsListResponse().from_dict(
             self._call_sisu_api(url_path, request_method="GET")
         )
+    def get_analysis_waterfall(self, analysis_id) -> WaterfallAnalysisResponse:
+        path = [f"api/v1/analyses/{analysis_id}/waterfall"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return WaterfallAnalysisResponse().from_dict(
+            self._call_sisu_api(url_path, request_method="GET")
+        )
